#ifndef H_CDW_LOGGING
#define H_CDW_LOGGING

#include "main.h"

cdw_rv_t cdw_logging_module_init(void);
void     cdw_logging_module_clean(void);

void cdw_logging_write(const char *format, ...);
void cdw_logging_write_separator(void);
cdw_rv_t cdw_logging_display_log(const char *title);
cdw_rv_t cdw_logging_display_log_conditional(const char *title);

#endif /* #ifndef H_CDW_LOGGING */
